==> jc-1.4.0.tar.gz: jas/jasError.h <==
// public class jas.jasError

// class file dependencies
// @dep_class 2979cbe9083c83dc jas_jasError
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_jas_jasError_H_
#define _JC_jas_jasError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_jasError$sub_refs	_jc_jas_jasError$sub_refs;
typedef struct _jc_jas_jasError$sub_nonrefs	_jc_jas_jasError$sub_nonrefs;
typedef struct _jc_jas_jasError$refs	_jc_jas_jasError$refs;
typedef struct _jc_jas_jasError$nonrefs	_jc_jas_jasError$nonrefs;
typedef struct _jc_jas_jasError$object	_jc_jas_jasError$object;

typedef const struct _jc_jas_jasError$vmethods	_jc_jas_jasError$vmethods;
typedef const struct _jc_jas_jasError$vtable	_jc_jas_jasError$vtable;
typedef const struct _jc_jas_jasError$vtype	_jc_jas_jasError$vtype;

// Constructors
extern void _jc_jas_jasError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_jasError$object *);
extern void _jc_jas_jasError$method$_init$c31b894660454d13(_jc_env *, struct _jc_jas_jasError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_jas_jasError$vmethods {
};

// Vtable
struct _jc_jas_jasError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_jas_jasError$vmethods	jas_jasError;
};

// Vtype
struct _jc_jas_jasError$vtype {
	_jc_type			type;
	_jc_jas_jasError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_jasError$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_jasError$refs {
    _jc_jas_jasError$sub_refs	jas_jasError;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_jasError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_jasError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_jas_jasError$sub_nonrefs	jas_jasError;
};

// Object instance structure
struct _jc_jas_jasError$object {
	_jc_jas_jasError$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_jasError$vtype	*vtype;
	_jc_jas_jasError$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_jasError$vtype _jc_jas_jasError$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_jasError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_jasError$class_object;

#endif	/* _JC_jas_jasError_H_ */

==> jc-1.4.6.tar.gz: jas/jasError.h <==
// public class jas.jasError

// class file dependencies
// @dep_class 2979cbe9083c83dc jas_jasError
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_jas_jasError_H_
#define _JC_jas_jasError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_jasError$sub_refs	_jc_jas_jasError$sub_refs;
typedef struct _jc_jas_jasError$sub_nonrefs	_jc_jas_jasError$sub_nonrefs;
typedef struct _jc_jas_jasError$refs	_jc_jas_jasError$refs;
typedef struct _jc_jas_jasError$nonrefs	_jc_jas_jasError$nonrefs;
typedef struct _jc_jas_jasError$object	_jc_jas_jasError$object;

typedef const struct _jc_jas_jasError$vmethods	_jc_jas_jasError$vmethods;
typedef const struct _jc_jas_jasError$vtable	_jc_jas_jasError$vtable;
typedef const struct _jc_jas_jasError$vtype	_jc_jas_jasError$vtype;

// Constructors
extern void _jc_jas_jasError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_jasError$object *) _JC_JCNI_ATTR;
extern void _jc_jas_jasError$method$_init$c31b894660454d13(_jc_env *, struct _jc_jas_jasError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_jasError$vmethods {
};

// Vtable
struct _jc_jas_jasError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_jas_jasError$vmethods	jas_jasError;
};

// Vtype
struct _jc_jas_jasError$vtype {
	_jc_type			type;
	_jc_jas_jasError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_jasError$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_jasError$refs {
    _jc_jas_jasError$sub_refs	jas_jasError;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_jasError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_jasError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_jas_jasError$sub_nonrefs	jas_jasError;
};

// Object instance structure
struct _jc_jas_jasError$object {
	_jc_jas_jasError$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_jasError$vtype	*vtype;
	_jc_jas_jasError$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_jasError$vtype _jc_jas_jasError$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_jasError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_jasError$class_object;

#endif	/* _JC_jas_jasError_H_ */
